@@ -7,7 +7,7 @@ use Mite::Miteception -all;
 extends 'Mite::App::Command' => { -version => '0.009000' };
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010003';
+our $VERSION   = '0.010004';
 
 sub abstract {
     return "Make your code ready to run.";
@@ -28,9 +28,12 @@ sub execute {
 
     my $project = $self->project;
 
+    # This is a hack to force Mite::* modules which are already loaded
+    # to be loaded again so Mite can compile itself.
+    #
     if ( $self->config->data->{dogfood} ) {
         $project->_module_fakeout_namespace(
-            $ENV{FAKEOUT_NAMESPACE} = sprintf 'A%02d::B%02d', int(rand 100), int(rand 100)
+            sprintf 'A%02d::B%02d', int(rand 100), int(rand 100)
         );
     }
 
