@@ -6,7 +6,7 @@ package Mite::Project;
 use Mite::Miteception -all;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010003';
+our $VERSION   = '0.010004';
 
 has sources =>
   is            => ro,
@@ -103,7 +103,7 @@ sub inject_mite_functions {
     warn "Gather: $package\n" if $self->debug;
 
     $source //= $self->source_for(
-        Path::Tiny::path( $ENV{MITE_COMPILE_SELF} // $file )
+        Path::Tiny::path( $Mite::REAL_FILENAME // $file )
     );
     $pkg //= $source->class_for(
         $package,
@@ -192,7 +192,9 @@ signature_for load_files => (
 sub load_files {
     my ( $self, $files, $inc_dir ) = @_;
 
-    local $ENV{MITE_COMPILE} = 1;
+    local $Mite::COMPILING = eval { $self->config->data->{shim} }
+        // $ENV{TEST_MITE_SHIM}
+        // do { warn 'Attempting to compile, but no shim in config'; exit 1; };
     local @INC = @INC;
     unshift @INC, $inc_dir if defined $inc_dir;
     for my $file (@$files) {
@@ -228,7 +230,7 @@ sub _load_file {
 
         do {
             local $@;
-            local $ENV{MITE_COMPILE_SELF} = "$file";
+            local $Mite::REAL_FILENAME = "$file";
             eval("$code; 1") or do die($@);
         };
 
